If you are using cpython you may need the ``libffi`` development package in
order to compile this module's dependencies.

* **Ubuntu**: ``apt-get install libffi-dev``
* **MacOS**: ``brew install libffi``
